%global namedreltag .Alpha6
%global namedversion %{version}%{?namedreltag}

Name:             hibernate-hql
Version:          1.0.0
Release:          %mkrel 0.6%{namedreltag}.2
Group:            Development/Java
Summary:          Hibernate Query Parser
License:          LGPLv2 and ASL 2.0
Url:              https://github.com/hibernate/hibernate-hql-parser
Source0:          https://github.com/hibernate/hibernate-hql-parser/archive/%{namedversion}.tar.gz

Source1:          https://repository.jboss.org/nexus/service/local/repositories/releases/content/org/hibernate/hql/%{name}-parser/%{namedversion}/%{name}-parser-%{namedversion}.pom
Source2:          https://repository.jboss.org/nexus/service/local/repositories/releases/content/org/hibernate/hql/%{name}-lucene/%{namedversion}/%{name}-lucene-%{namedversion}.pom

BuildRequires:    maven-local
BuildRequires:    mvn(org.antlr:antlr-runtime) >= 3.4
BuildRequires:    mvn(org.antlr:antlr3-maven-plugin)
BuildRequires:    mvn(org.antlr:stringtemplate)
BuildRequires:    mvn(org.apache.lucene:lucene-core:3)
BuildRequires:    mvn(org.apache.lucene:lucene-analyzers:3)
BuildRequires:    mvn(org.apache.lucene:lucene-facet:3)
BuildRequires:    mvn(org.bsc.maven:maven-processor-plugin)
BuildRequires:    mvn(org.hibernate:hibernate-search-engine)
BuildRequires:    mvn(org.hibernate.javax.persistence:hibernate-jpa-2.0-api)
BuildRequires:    mvn(org.jboss.logging:jboss-logging)
BuildRequires:    mvn(org.jboss.logging:jboss-logging-processor)

BuildArch:        noarch

%description
Experimental new parser for HQL and JP-QL queries, to convert these into SQL
and other different targets such as Lucene queries, Map/Reduce queries for
NoSQL stores, make it possible to perform more sophisticated SQL
transformations.

%package javadoc
Summary:          Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}-parser-%{namedversion}

find . -name '*.jar' -delete
find . -name '*.class' -delete

sed -i "s,59 Temple Place,51 Franklin Street,;s,Suite 330,Fifth Floor,;s,02111-1307,02110-1301," license.txt

cp %{SOURCE1} parser/pom.xml
cp %{SOURCE2} lucene/pom.xml
# This is a dummy POM added just to ease building in the RPM platforms
cat > pom.xml << EOF
<?xml version="1.0" encoding="UTF-8"?>
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">

    <modelVersion>4.0.0</modelVersion>
    <groupId>org.hibernate.hql</groupId>
    <artifactId>hibernate-hql-parent</artifactId>
    <version>%{namedversion}</version>
    <packaging>pom</packaging>
    <name>Hibernate HQL/JP-QL Parent</name>
    <description>Hibernate HQL/JP-QL</description>

    <modules>
      <module>parser</module>
      <module>lucene</module>
    </modules>
  
</project>
EOF

%pom_add_plugin "org.bsc.maven:maven-processor-plugin:2.0.2 " parser '
<configuration>
    <defaultOutputDirectory>${project.build.directory}/generated-sources/logging</defaultOutputDirectory>
    <processors>
        <processor>org.jboss.logging.processor.apt.LoggingToolsProcessor</processor>
    </processors>
    <compilerArguments>
      -nowarn -proc:only -encoding UTF-8 
      -source 1.6 -target 1.6 
      -sourcepath ${project.build.directory}/generated-sources/antlr3 
      -Adebug=true -AskipTranslations=true
    </compilerArguments>
</configuration>
<executions>
    <execution>
        <id>process</id>
        <phase>generate-sources</phase>
        <goals>
            <goal>process</goal>
        </goals>
    </execution>
</executions>
<dependencies>
    <dependency>
        <groupId>org.jboss.logging</groupId>
        <artifactId>jboss-logging-processor</artifactId>
        <version>1.0.3.Final</version>
    </dependency>
</dependencies>'

%pom_add_plugin "org.antlr:antlr3-maven-plugin:3.4" parser " 
<executions>
  <execution>
   <phase>generate-sources</phase>
   <goals>
    <goal>antlr</goal>
   </goals>
   <configuration>
    <sourceDirectory>src/main/antlr</sourceDirectory>
   </configuration>
 </execution>
</executions>"

# package org.antlr.stringtemplate does not exist
%pom_add_dep org.antlr:stringtemplate:3.3-SNAPSHOT:provided parser
# Force usage of lucene3 used by hibernate-search-engine
%pom_add_dep org.apache.lucene:lucene-core:3:provided lucene
%pom_add_dep org.apache.lucene:lucene-analyzers:3:provided lucene
%pom_add_dep org.apache.lucene:lucene-facet:3:provided lucene

%mvn_package :hibernate-hql-parent __noinstall

%build
%mvn_build -f -- -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

%files -f .mfiles
%doc README.md
%license copyright.txt license.txt

%files javadoc -f .mfiles-javadoc
%license copyright.txt license.txt



%changelog
* Wed Mar 02 2016 neoclust <neoclust> 1.0.0-0.6.Alpha6.2.mga6
+ Revision: 982482
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.0.0-0.6.Alpha6.1.mga6
+ Revision: 977225
- sync package hibernate-hql with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sat Dec 27 2014 pterjan <pterjan> 1.0.0-0.3.Alpha6.2.mga5
+ Revision: 806449
- Clean rebuild
- Update lucene dependency
- Sync with Fedora 21 (update to 1.0.0.Alpha6)

* Wed Oct 15 2014 umeabot <umeabot> 1.0.0-0.2.Alpha5.3.mga5
+ Revision: 746921
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Dec 29 2013 dmorgan <dmorgan> 1.0.0-0.2.Alpha5.1.mga4
+ Revision: 562959
- imported package hibernate-hql


* Wed Oct 23 2013 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.0.0-0.2.Alpha5
- Rebuild to regenerate broken POMs
- Related: rhbz#1021484

* Thu Oct 10 2013 Marek Goldmann <mgoldman@redhat.com> - 1.0.0-0.1.Alpha5
- Initial import


